import { writeFile } from 'node:fs/promises';
import nodePath from 'node:path';
import m3u from 'm3u';
import type { Playlist, SongMeta } from './services/jellyfin.ts';
import { writeFileAndCreateFolders } from './helpers.ts';
import { getLocalPath, getSongLocalFileName } from './fileDownloader.ts';

const createM3U = (name: string, songlist: SongMeta[]) => {
  const m3uWriter = m3u.writer();
  for (const song of songlist) {
    const path = getLocalPath(song.Path);
    const name = getSongLocalFileName(song);

    m3uWriter.file('.' + nodePath.join(path, name));
  }
  return m3uWriter.toString();
};

export const writeM3UFile = async (path: string, playlist: Playlist) => {
  const name = playlist.Name || playlist.Id;
  const contents = createM3U(name, playlist.songList);
  return writeFileAndCreateFolders(nodePath.join(path, `${name}.m3u`), contents);
};
